## 3.18.0.3 (2023-03-29)

Remove unnecessary ellipsis expressions (#9976)

Ignore flake8 F821 warnings in stub files

## 3.18.0.2 (2023-03-28)

Add defaults for third-party stubs Q-T (#9959)

## 3.18.0.1 (2023-02-21)

Stubtest settings: change `ignore_missing_stub` default to `false` (#9779)

If you're reading about this commit from an autogenerated changelog entry, this should have no user-visible impact on how the stubs are interpreted by a type checker; it's just an internal change to how typeshed's tests work.

## 3.18.0.0 (2022-11-15)

[stubsabot] Bump simplejson to 3.18.* (#9198)

Release: https://pypi.org/pypi/simplejson/3.18.0
Homepage: https://github.com/simplejson/simplejson
Diff: https://github.com/simplejson/simplejson/compare/v3.17.6...v3.18.0

Stubsabot analysis of the diff between the two releases:
 - 0 public Python files have been added.
 - 0 files included in typeshed's stubs have been deleted.
 - 3 files included in typeshed's stubs have been modified or renamed: `simplejson/__init__.py`, `simplejson/decoder.py`, `simplejson/encoder.py`.
 - Total lines of Python code added: 63.
 - Total lines of Python code deleted: 25.

If stubtest fails for this PR:
- Leave this PR open (as a reminder, and to prevent stubsabot from opening another PR)
- Fix stubtest failures in another PR, then close this PR

Note that you will need to close and re-open the PR in order to trigger CI

Co-authored-by: stubsabot <>

## 3.17.7.2 (2022-11-08)

add default for simplejson.JSONEncoder.iterencode (#9135)

https://github.com/simplejson/simplejson/blob/43645252224d4e529c22cb78ac42f241d6426073/simplejson/encoder.py#L304

## 3.17.7.1 (2022-10-20)

Remove `simplejson` from `pyright`'s exclude (#8945)

## 3.17.7 (2022-07-12)

Import `Match` and `Pattern` from `re`, not `typing` (#8277)

## 3.17.6 (2022-04-27)

Remove Python 2 support from simplejson (#7704)

## 3.17.5 (2022-04-16)

Use `TypeAlias` where possible for type aliases (#7630)

## 3.17.4 (2022-03-16)

Use PEP 604 syntax wherever possible (#7493)

## 3.17.2 (2021-12-05)

Create simplejson.errors (#6492)

## 3.17.1 (2021-10-12)

Add star to all non-0.1 versions (#6146)

